@@ -8,10 +8,12 @@ from functools import wraps
 import traceback
 from pathlib import Path
 
+
 class BaseTrainingContainer:
     """
-        A set of tasks for setup and cleanup of container
+    A set of tasks for setup and cleanup of container
     """
+
     def __init__(self, container_environment, container_logger):
         self.container_logger = container_logger
         self.container_environment = container_environment
@@ -19,7 +21,12 @@ class BaseTrainingContainer:
     def startup(self):
         """start up tasks executed on a container task setup"""
         self.container_logger.info("Setting up Instance")
-        if self.container_environment.environment_variables('MLDOCK_STAGE', default=None) == "prod":
+        if (
+            self.container_environment.environment_variables(
+                "MLDOCK_STAGE", default=None
+            )
+            == "prod"
+        ):
             self.container_logger.info("Env == Prod")
             self.container_environment.setup_inputs()
             self.container_environment.setup_model_artifacts()
@@ -28,7 +35,12 @@ class BaseTrainingContainer:
     def cleanup(self):
         """clean up tasks executed on container task complete"""
         self.container_logger.info("Running Cleanup Script")
-        if self.container_environment.environment_variables('MLDOCK_STAGE', default=None) == "prod":
+        if (
+            self.container_environment.environment_variables(
+                "MLDOCK_STAGE", default=None
+            )
+            == "prod"
+        ):
             self.container_logger.info("Env == Prod")
             self.container_environment.cleanup_model_artifacts()
             self.container_environment.cleanup_outputs()
@@ -36,34 +48,29 @@ class BaseTrainingContainer:
 
     def wrap(self, function):
         """execution handler for training container worflow"""
+
         @wraps(function)
         def func_wrapper(*args, **kwargs):
             """
-                Wrapper function to decorate function
+            Wrapper function to decorate function
             """
             try:
                 self.startup()
                 return function(
-                    *args,
-                    self.container_environment,
-                    self.container_logger,
-                    **kwargs
+                    *args, self.container_environment, self.container_logger, **kwargs
                 )
             except Exception as exception:
                 # Write out an error file. This will be returned as the failureReason in the
                 # DescribeTrainingJob result.
                 trc = traceback.format_exc()
                 log_file_path = Path(
-                    self.container_environment.output_data_dir,
-                    'failure'
-                )
-                with open(log_file_path, 'w') as file_:
-                    file_.write(
-                        f'Exception during training: {str(exception)}\n{trc}'
+                    self.container_environment.output_data_dir, "failure"
                 )
+                with open(log_file_path, "w") as file_:
+                    file_.write(f"Exception during training: {str(exception)}\n{trc}")
                 # Printing this causes the exception to be in the training job logs, as well.
                 self.container_logger.error(
-                    f'Exception during training: {str(exception)}\n{trc}'
+                    f"Exception during training: {str(exception)}\n{trc}"
                 )
                 raise
             finally:
@@ -71,11 +78,13 @@ class BaseTrainingContainer:
 
         return func_wrapper
 
+
 class BaseServingContainer:
     """
-        A set of tasks for setup and cleanup of container instance and
-        between worker starts & completes
+    A set of tasks for setup and cleanup of container instance and
+    between worker starts & completes
     """
+
     def __init__(self, container_environment, container_logger):
         self.container_environment = container_environment
         self.container_logger = container_logger
@@ -88,7 +97,12 @@ class BaseServingContainer:
         """start up tasks executed on a container task setup"""
         self.container_logger.info("Setting up instance")
 
-        if self.container_environment.environment_variables('MLDOCK_STAGE', default=None) == "prod":
+        if (
+            self.container_environment.environment_variables(
+                "MLDOCK_STAGE", default=None
+            )
+            == "prod"
+        ):
             self.container_logger.info("Env == Prod")
             self.container_environment.setup_model_artifacts()
         self.container_logger.info("Setup Complete")
@@ -104,35 +118,30 @@ class BaseServingContainer:
 
     def wrap(self, function):
         """execution handler for serving container worflow"""
+
         @wraps(function)
         def func_wrapper(*args, **kwargs):
             """
-                Wrapper function to decorate function
+            Wrapper function to decorate function
             """
             try:
                 self.startup_worker()
 
                 return function(
-                    *args,
-                    self.container_environment,
-                    self.container_logger,
-                    **kwargs
+                    *args, self.container_environment, self.container_logger, **kwargs
                 )
             except Exception as exception:
                 # Write out an error file. This will be returned as the failureReason in the
                 # DescribeTrainingJob result.
                 trc = traceback.format_exc()
                 log_file_path = Path(
-                    self.container_environment.output_data_dir,
-                    'failure'
-                )
-                with open(log_file_path, 'w') as file_:
-                    file_.write(
-                        f'Exception during training: {str(exception)}\n{trc}'
+                    self.container_environment.output_data_dir, "failure"
                 )
+                with open(log_file_path, "w") as file_:
+                    file_.write(f"Exception during training: {str(exception)}\n{trc}")
                 # Printing this causes the exception to be in the training job logs, as well.
                 self.container_logger.error(
-                    f'Exception during training: {str(exception)}\n{trc}'
+                    f"Exception during training: {str(exception)}\n{trc}"
                 )
                 raise
             finally:
