@@ -1,14 +1,12 @@
 """
-    CONTINAER LIFECYCLE MANAGEMENT
-
+    CONTAINER LIFECYCLE MANAGEMENT
     Provides a central place to instantiate container environment, loggers and container assets management objects.
     Call these instantiated objects in to other scripts using a simple import.
 """
 import logging
-from mldock.platform_helpers.mldock.configuration.environment.base import (
+from mldock.platform_helpers.mldock.configuration.environment import (
     BaseEnvironment,
 )
-
 from src.assets import TrainingContainer, ServingContainer
 
 # Init Environment
